@@ -39,7 +39,6 @@ struct _BjbApplication
 {
   GtkApplication  parent_instance;
 
-  GtkCssProvider *css_provider;
   BijiManager    *manager;
   BjbSettings    *settings;
 
@@ -128,13 +127,26 @@ bijiben_new_window_internal (BjbApplication *self,
                              BijiNoteObj    *note)
 {
   BjbWindowBase *window;
+  BjbController *controller;
   GList         *windows;
   gboolean       not_first_window;
 
   windows = gtk_application_get_windows (GTK_APPLICATION (self));
   not_first_window = (gboolean) g_list_length (windows);
 
+  for (GList *l = windows; l != NULL; l = l->next)
+  {
+      BjbWindowBase *window = BJB_WINDOW_BASE (l->data);
+      if (bjb_window_base_get_note (window) == note)
+      {
+          gtk_window_present (GTK_WINDOW (window));
+          return;
+      }
+  }
+
   window = BJB_WINDOW_BASE (bjb_window_base_new (note));
+  controller = bjb_window_base_get_controller (window);
+  bjb_controller_apply_needle (controller);
   g_signal_connect (window, "activated",
                     G_CALLBACK (on_window_activated_cb), self);
 
@@ -142,6 +154,14 @@ bijiben_new_window_internal (BjbApplication *self,
 
   if (not_first_window)
     gtk_window_set_position (GTK_WINDOW (window), GTK_WIN_POS_CENTER);
+
+  if (g_strcmp0 (PROFILE, "") != 0)
+    {
+      GtkStyleContext *style_context;
+
+      style_context = gtk_widget_get_style_context (GTK_WIDGET (window));
+      gtk_style_context_add_class (style_context, "devel");
+    }
 }
 
 static gboolean
@@ -174,10 +194,14 @@ bijiben_new_window_for_note (GApplication *app,
 static void
 bijiben_activate (GApplication *app)
 {
-  GList *windows = gtk_application_get_windows (GTK_APPLICATION (app));
+  BjbApplication *self;
 
-  // ensure the last used window is raised
-  gtk_window_present (g_list_nth_data (windows, 0));
+  self = BJB_APPLICATION (app);
+
+  if (!self->is_loaded)
+    return;
+
+  bijiben_new_window_internal (self, NULL);
 }
 
 
@@ -192,15 +216,17 @@ bijiben_open (GApplication  *application,
 {
   BjbApplication *self;
   gint i;
-  g_autofree gchar *path = NULL;
 
   self = BJB_APPLICATION (application);
 
   for (i = 0; i < n_files; i++)
   {
+    g_autofree char *path = NULL;
+
     path = g_file_get_parse_name (files[i]);
     if (!bijiben_open_path (self, path, NULL))
-      g_queue_push_head (&self->files_to_open, path);
+      g_queue_push_head (&self->files_to_open,
+                         g_steal_pointer (&path));
   }
 }
 
@@ -210,6 +236,7 @@ bjb_application_init (BjbApplication *self)
   self->settings = bjb_settings_new ();
   g_queue_init (&self->files_to_open);
 
+  g_set_prgname ("org.gnome.Notes");
   gtk_window_set_default_icon_name ("org.gnome.Notes");
 }
 
@@ -224,6 +251,27 @@ bijiben_import_notes (BjbApplication *self, gchar *uri)
                            uri);
 }
 
+void
+on_new_note_cb (GSimpleAction *action,
+                GVariant      *parameter,
+                gpointer       user_data)
+{
+  BjbApplication *self;
+  BijiItem *item;
+
+  self = BJB_APPLICATION (user_data);
+
+  if (!self->is_loaded)
+      return;
+
+  self->new_note = FALSE;
+  item = BIJI_ITEM (biji_manager_note_new (
+                      self->manager,
+                      NULL,
+                      bjb_settings_get_default_location (self->settings)));
+  bijiben_new_window_internal (self, BIJI_NOTE_OBJ (item));
+}
+
 void
 on_import_notes_cb (GSimpleAction *action,
                     GVariant      *parameter,
@@ -290,16 +338,15 @@ text_size_mapping_set (const GValue       *value,
 static void
 bjb_apply_style (BjbApplication *self)
 {
-  if (self->css_provider == NULL)
-    {
-      g_autoptr(GFile) file = g_file_new_for_uri ("resource:///org/gnome/Notes/style.css");
-      self->css_provider = gtk_css_provider_new ();
-      gtk_css_provider_load_from_file (self->css_provider, file, NULL);
+  g_autoptr(GtkCssProvider) css_provider = NULL;
 
-      gtk_style_context_add_provider_for_screen (gdk_screen_get_default (),
-                                                 GTK_STYLE_PROVIDER (self->css_provider),
-                                                 GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
-    }
+  css_provider = gtk_css_provider_new ();
+  gtk_css_provider_load_from_resource (css_provider,
+                                       "/org/gnome/Notes/style.css");
+
+  gtk_style_context_add_provider_for_screen (gdk_screen_get_default (),
+                                             GTK_STYLE_PROVIDER (css_provider),
+                                             GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
 }
 
 static void
@@ -341,6 +388,7 @@ manager_ready_cb (GObject *source,
 }
 
 static GActionEntry app_entries[] = {
+  { "new-note", on_new_note_cb, NULL, NULL, NULL },
   { "import-notes", on_import_notes_cb, NULL, NULL, NULL },
   { "view-trash", on_view_trash_cb, NULL, NULL, NULL },
   { "text-size", NULL, "s", "'medium'", NULL },
@@ -426,6 +474,7 @@ bijiben_application_local_command_line (GApplication *application,
   g_autoptr(GError) error = NULL;
   gint argc = 0;
   gchar **argv = NULL;
+  GPtrArray *files;
 
   const GOptionEntry options[] = {
     { "version", 0, 0, G_OPTION_ARG_NONE, &version,
@@ -481,14 +530,25 @@ bijiben_application_local_command_line (GApplication *application,
 
   self = BJB_APPLICATION (application);
 
-  if (!self->new_note && remaining != NULL)
+  files = g_ptr_array_new_with_free_func (g_object_unref);
+
+  if (self->new_note && g_application_get_is_remote (application))
+  {
+    g_action_group_activate_action (G_ACTION_GROUP(application), "new-note", NULL);
+  }
+  else if (remaining != NULL)
   {
     gchar **args;
 
     for (args = remaining; *args; args++)
-      if (!bijiben_open_path (self, *args, NULL))
-        g_queue_push_head (&self->files_to_open, g_strdup (*args));
+      g_ptr_array_add (files, g_file_new_for_commandline_arg (*args));
+    g_application_open (application, (GFile **)files->pdata, files->len, "");
   }
+  else
+  {
+    g_application_activate (application);
+  }
+  g_ptr_array_free (files, TRUE);
 
  out:
   g_strfreev (remaining);
@@ -502,7 +562,6 @@ bijiben_finalize (GObject *object)
 {
   BjbApplication *self = BJB_APPLICATION (object);
 
-  g_clear_object (&self->css_provider);
   g_clear_object (&self->manager);
   g_clear_object (&self->settings);
   g_queue_foreach (&self->files_to_open, (GFunc) g_free, NULL);
@@ -529,7 +588,7 @@ BjbApplication *
 bjb_application_new (void)
 {
   return g_object_new (BJB_TYPE_APPLICATION,
-                       "application-id", "org.gnome.Notes",
+                       "application-id", BIJIBEN_APPLICATION_ID,
                        "flags", G_APPLICATION_HANDLES_OPEN,
                        NULL);
 }
@@ -614,7 +673,7 @@ bjb_app_about (BjbApplication *self)
                          "artists", artists,
                          "translator-credits", _("translator-credits"),
                          "website", "https://wiki.gnome.org/Apps/Notes",
-                         "logo-icon-name", "org.gnome.Notes",
+                         "logo-icon-name", BIJIBEN_APPLICATION_ID,
                          NULL);
 }
 
