@@ -17,8 +17,7 @@
  * with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef BJB_EDITOR_TOOLBAR_H
-#define BJB_EDITOR_TOOLBAR_H
+#pragma once
 
 #include "bjb-note-view.h"
 
@@ -26,18 +25,9 @@ G_BEGIN_DECLS
 
 #define BJB_TYPE_EDITOR_TOOLBAR (bjb_editor_toolbar_get_type ())
 
-G_DECLARE_FINAL_TYPE (BjbEditorToolbar, bjb_editor_toolbar, BJB, EDITOR_TOOLBAR, GtkActionBar);
-
-typedef struct _BjbEditorToolbarPrivate BjbEditorToolbarPrivate;
-
-struct _BjbEditorToolbar
-{
-  GtkActionBar parent;
-};
+G_DECLARE_FINAL_TYPE (BjbEditorToolbar, bjb_editor_toolbar, BJB, EDITOR_TOOLBAR, GtkActionBar)
 
 GtkWidget *bjb_editor_toolbar_new (BjbNoteView *bjb_note_view,
                                    BijiNoteObj *biji_note_obj);
 
 G_END_DECLS
-
-#endif /* BJB_EDITOR_TOOLBAR_H */
